/// <reference types="node" />
import { EventEmitter } from 'events';
import { SECURE_MODE } from '../constants';
import { DeviceInfo } from '../deviceinfo';
import { UpstreamService, CommandService } from '../services';
import { INodeStyleCallback, IDeviceClientOptions, IDeviceTransport, IDeviceTransportCtor } from '../interfaces';
export interface IUpstreamOptions {
    qos?: 0 | 1;
    /**
     * Identifies whether it is necessary to wait for the server to return. Default is true;
     * if set to false, the callback function will be called immediately after the message is sent successfully
     */
    needReply?: boolean;
}
export interface IDeviceUpstreamOptions extends IUpstreamOptions {
    deviceInfo?: DeviceInfo;
}
export declare class DeviceClient extends EventEmitter {
    protected _transport: IDeviceTransport;
    protected _deviceInfo: DeviceInfo;
    protected _secureMode: SECURE_MODE;
    deviceData: UpstreamService;
    deviceCommand: CommandService;
    constructor(TransportCtor: IDeviceTransportCtor, options: IDeviceClientOptions);
    private _validateClientOptions;
    readonly connected: boolean;
    readonly reconnected: boolean;
    readonly deviceInfo: DeviceInfo;
    readonly secureMode: SECURE_MODE;
    /**
     * Connect to the cloud
     *
     * After the connection is successful, return the device secret of the device
     */
    connect(): Promise<string>;
    /**
     * Closes the transport connection and destroys the client resources.
     *
     * *Note: After calling this method the Client object cannot be reused.*
     */
    close(): Promise<void>;
    /**
     * Subscribe dynamic activate command of the device
     *
     * Once activated, cloud will return the device secret of the device
     */
    protected _onDynamicDeviceActivate(callback: INodeStyleCallback<string>): void;
}
