"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const constants_1 = require("../constants");
const device_client_1 = require("./device_client");
const gateway_service_1 = __importDefault(require("../services/gateway_service"));
const debug = debug_1.default('enos-sdk-core:gateway_client');
class GatewayClient extends device_client_1.DeviceClient {
    constructor(TransportCtor, options) {
        super(TransportCtor, options);
        this.loginedSubDeviceMap = new Map();
        this.subDeviceManagement = new gateway_service_1.default(this, this._transport);
        this._transport.on('connect', () => {
            // Auto connect the logined sub-devices once the client is reconnected
            if (this.reconnected) {
                this._autoLoginSubDevices();
            }
        });
    }
    _autoLoginSubDevices() {
        if (this.loginedSubDeviceMap.size > 0) {
            this.subDeviceManagement.batchLoginSubDevice({
                subDevices: Array.from(this.loginedSubDeviceMap.values())
            }).then((result) => {
                if (result.code === constants_1.SUCCESS_CODE) {
                    debug('auto login sub-devices');
                }
                else {
                    debug('failed to auto login sub-devices');
                }
            }).catch(() => {
                debug('failed to auto login sub-devices');
            });
        }
    }
}
exports.GatewayClient = GatewayClient;
