"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const utils_1 = require("./utils");
class DeviceInfo {
    constructor(deviceInfo) {
        this.productKey = deviceInfo.productKey;
        this.productSecret = deviceInfo.productSecret || '';
        this.deviceKey = deviceInfo.deviceKey;
        this.deviceSecret = deviceInfo.deviceSecret || '';
    }
    getSecureMode() {
        if (this.deviceSecret) {
            return constants_1.SECURE_MODE.VIA_DEVICE_SECRET;
        }
        if (this.productSecret) {
            return constants_1.SECURE_MODE.VIA_PRODUCT_SECRET;
        }
        return undefined;
    }
}
exports.DeviceInfo = DeviceInfo;
class SubDeviceInfo extends DeviceInfo {
    constructor(deviceInfo) {
        super({
            productKey: deviceInfo.productKey,
            productSecret: deviceInfo.productSecret,
            deviceKey: deviceInfo.deviceKey,
            deviceSecret: deviceInfo.deviceSecret
        });
        const { clientId, timestamp, cleanSession } = deviceInfo;
        this._signMethod = constants_1.SIGN_METHOD.SHA256;
        this.clientId = clientId || this.deviceKey;
        this.cleanSession = cleanSession || false;
        this.timestamp = timestamp || 0;
    }
    setClientId(clientId) {
        this.clientId = clientId;
    }
    getLoginInfo(signMethod, signTimestamp) {
        const signMethodName = signMethod || this._signMethod;
        const timestamp = signTimestamp || this.timestamp || new Date().getTime();
        const signStr = utils_1.sign({
            timestamp,
            productKey: this.productKey,
            deviceKey: this.deviceKey,
            clientId: this.clientId
        }, this.deviceSecret || '', signMethodName);
        const subDeviceLoginInfo = {
            timestamp,
            productKey: this.productKey,
            deviceKey: this.deviceKey,
            clientId: this.clientId,
            signMethod: signMethodName,
            sign: signStr
        };
        if (this.cleanSession) {
            subDeviceLoginInfo.cleanSession = 'true';
        }
        return subDeviceLoginInfo;
    }
}
exports.SubDeviceInfo = SubDeviceInfo;
exports.default = DeviceInfo;
