"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const VERSION = '1.0';
class UpstreamRequest {
    constructor(topic, params, isRawData = false) {
        this.messageId = '';
        this.version = VERSION;
        this.params = params;
        this._topic = topic;
        this._isRawData = isRawData;
    }
    getMessageId() {
        return this.messageId;
    }
    setMessageId(messageId) {
        this.messageId = messageId;
    }
    getTopicName() {
        return this._topic.getTopicName();
    }
    getResponseTopicName() {
        return this._topic.getResponseTopicName();
    }
    isRawData() {
        return this._isRawData;
    }
    getPayload() {
        // If it is raw data, the payload is the data itself
        if (this._isRawData) {
            return this.params;
        }
        return {
            id: this.messageId,
            version: this.version,
            params: this.params,
            method: this._topic.getMethod()
        };
    }
}
exports.UpstreamRequest = UpstreamRequest;
class MeasurePointBatchRequest extends UpstreamRequest {
    constructor() {
        super(...arguments);
        /**
         * Whether to allow sending measurement point data for offline devices. False by default.
         * If sending data of offline device is not allowed and the request contains an offline device, the entire request is declined.
         */
        this._allowOfflineSubDevice = false;
        /**
         * Whether to neglect invalid measurement point data in a request. False by default.
         * If the value is set to false and the request contains invalid measurement point data, the entire request is declined.
         */
        this._skipInvalidMeasurepoints = false;
    }
    setAllowOfflineSubDevice(allowOfflineSubDevice) {
        this._allowOfflineSubDevice = allowOfflineSubDevice;
    }
    setSkipInvalidMeasurepoints(skipInvalidMeasurepoints) {
        this._skipInvalidMeasurepoints = skipInvalidMeasurepoints;
    }
    getPayload() {
        return Object.assign(Object.assign({}, super.getPayload()), { allowOfflineSubDevice: this._allowOfflineSubDevice, skipInvalidMeasurepoints: this._skipInvalidMeasurepoints });
    }
}
exports.MeasurePointBatchRequest = MeasurePointBatchRequest;
