"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class UpstreamResponse {
    constructor(payload) {
        const msg = this._decodePayload(payload);
        if (!msg) {
            throw new Error(`decode payload ${(payload || '').toString()} fail: `);
        }
        this.id = msg.id;
        this.code = msg.code;
        this.message = msg.message;
        this.data = msg.data;
    }
    _decodePayload(payload) {
        if (!payload) {
            return null;
        }
        let msg = {};
        try {
            msg = JSON.parse(payload.toString());
            // The `data` field in the msg object may be an empty object {}, a string, an object or an array
            // After the string with only number strings are converted with `JSON.parse`, it will be converted to the `number` type.
            // So only the common object and array scenes will be converted, and the other scenes will be output as they are.
            if (msg && msg.data && typeof msg.data !== 'object') {
                const parsedData = JSON.parse(msg.data);
                if (typeof parsedData === 'object') {
                    msg.data = parsedData;
                }
            }
            return msg;
        }
        catch (e) {
            return null;
        }
    }
}
exports.UpstreamResponse = UpstreamResponse;
