import Service from '../service';
import { IUpstreamResponse } from '../../message';
import { IDeviceUpstreamOptions, DeviceClient } from '../../client/device_client';
interface IQueryAttributeUpstreamOptions extends IDeviceUpstreamOptions {
    attributeIds?: string[];
}
interface IUpdateAttributeUpstreamOptions extends IDeviceUpstreamOptions {
    attributeMap: Directory<Object>;
}
interface IDeleteAttributeUpstreamOptions extends IDeviceUpstreamOptions {
    attributeIds: string[];
}
export default class AttributeService extends Service<DeviceClient> {
    /**
     * Query attributes
     *
     * 1. If the specified attribute identifier list is empty, the cloud returns all attributes having values
     * 2. If the attributes to be queried has no value, it will not be in the returned list
     */
    queryAttribute(queryParams: IQueryAttributeUpstreamOptions): Promise<IUpstreamResponse<Directory<Object>>>;
    /**
     * Update attributes
     *
     * 1. The updated attributes must be existing attributes of the device, and the value type must match
     * 2. The updating operation is atomic; As long as one of the attributes does not meet the specifications, the other attributes will not be updated
     */
    updateAttribute(updateParams: IUpdateAttributeUpstreamOptions): Promise<IUpstreamResponse<void>>;
    /**
     * Delete attributes
     *
     * 1. Just delete the value of the attribute, the attribute itself is still on the device
     * 2. After deleting, you can reset the value of the attribute through `updateAttribute` method
     */
    deleteAttribute(deleteParams: IDeleteAttributeUpstreamOptions): Promise<IUpstreamResponse<void>>;
}
export {};
