"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const service_1 = __importDefault(require("../service"));
const topic_1 = require("../../topic");
const attributeTopics = __importStar(require("./attribute_topics"));
const utils_1 = require("../../utils");
const message_1 = require("../../message");
class AttributeService extends service_1.default {
    /**
     * Query attributes
     *
     * 1. If the specified attribute identifier list is empty, the cloud returns all attributes having values
     * 2. If the attributes to be queried has no value, it will not be in the returned list
     */
    queryAttribute(queryParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._validateParams(queryParams);
            if (queryParams && queryParams.attributeIds) {
                assert_1.default(Array.isArray(queryParams.attributeIds), 'attributeIds should be an array');
            }
            const params = this._extractParams(queryParams);
            const topic = new topic_1.Topic(attributeTopics.queryAttributeTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, { attributes: (queryParams && queryParams.attributeIds) || [] });
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
    /**
     * Update attributes
     *
     * 1. The updated attributes must be existing attributes of the device, and the value type must match
     * 2. The updating operation is atomic; As long as one of the attributes does not meet the specifications, the other attributes will not be updated
     */
    updateAttribute(updateParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._validateParams(updateParams);
            assert_1.default(updateParams && updateParams.attributeMap, 'attributeMap is required');
            assert_1.default(typeof updateParams.attributeMap === 'object', 'attributeMap should be in {key:value} format');
            const params = this._extractParams(updateParams);
            const topic = new topic_1.Topic(attributeTopics.updateAttributeTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, { attributes: (updateParams && updateParams.attributeMap) || {} });
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
    /**
     * Delete attributes
     *
     * 1. Just delete the value of the attribute, the attribute itself is still on the device
     * 2. After deleting, you can reset the value of the attribute through `updateAttribute` method
     */
    deleteAttribute(deleteParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._extractParams(deleteParams);
            assert_1.default(deleteParams && deleteParams.attributeIds, 'attributeIds is required');
            assert_1.default(Array.isArray(deleteParams.attributeIds), 'attributeIds should be an array');
            const params = this._extractParams(deleteParams);
            const topic = new topic_1.Topic(attributeTopics.deleteAttributeTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, { attributes: (deleteParams && deleteParams.attributeIds) || [] });
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
}
exports.default = AttributeService;
