"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const service_1 = __importDefault(require("../service"));
const topic_1 = require("../../topic");
const commandTopics = __importStar(require("./command_topics"));
class CommandService extends service_1.default {
    onInvokeService(serviceName, deviceInfo, callback) {
        assert_1.default(serviceName, '"serviceName" is required');
        assert_1.default(typeof serviceName === 'string', '"serviceName" should be a string');
        let newCallback = callback;
        let finalDeviceInfo = this._client.deviceInfo;
        if (deviceInfo) {
            if (typeof deviceInfo === 'function') {
                newCallback = deviceInfo;
            }
            else {
                finalDeviceInfo = deviceInfo;
            }
        }
        assert_1.default(newCallback, 'callback is required');
        assert_1.default(typeof newCallback === 'function', 'callback should be a function');
        const topic = new topic_1.Topic(commandTopics.serviceTopic, finalDeviceInfo, serviceName);
        this._transport.onCommand(topic, newCallback);
    }
    onSetMeasurepoint(deviceInfo, callback) {
        let newCallback = callback;
        let finalDeviceInfo = this._client.deviceInfo;
        if (deviceInfo) {
            if (typeof deviceInfo === 'function') {
                newCallback = deviceInfo;
            }
            else {
                finalDeviceInfo = deviceInfo;
            }
        }
        assert_1.default(newCallback, 'callback is required');
        assert_1.default(typeof newCallback === 'function', 'callback should be a function');
        const topic = new topic_1.Topic(commandTopics.setMeasurePointTopic, finalDeviceInfo);
        this._transport.onCommand(topic, newCallback);
    }
    /**
     * Called when the device received raw data from the cloud
     */
    onModelDownRaw(callback) {
        const topic = new topic_1.Topic(commandTopics.modelDownRawTopic, this._client.deviceInfo);
        this._transport.onRawDataCommand(topic, callback);
    }
}
exports.default = CommandService;
