"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
class Service {
    constructor(client, transport) {
        this._client = client;
        this._transport = transport;
    }
    /**
     * Extra needed params from upstream params
     */
    _extractParams(upstreamParams) {
        const result = {
            deviceInfo: this._client.deviceInfo,
            upstreamOptions: {}
        };
        const upstreamOptionFields = ['qos', 'needReply'];
        if (upstreamParams) {
            Object.keys(upstreamParams).forEach((key) => {
                if (upstreamOptionFields.indexOf(key) > -1) {
                    result.upstreamOptions[key] = upstreamParams[key];
                }
            });
            if (upstreamParams.deviceInfo) {
                result.deviceInfo = upstreamParams.deviceInfo;
            }
        }
        return result;
    }
    /**
     * Validate common upstream-options, including `qos` and `needReply`
     */
    _validateParams(params) {
        if (params && params.qos) {
            assert_1.default(params.qos >= 0 && params.qos < 2, 'only qos 0 and 1 is support in current version');
        }
        if (params && params.needReply) {
            assert_1.default(typeof params.needReply === 'boolean', 'needReply should be boolean');
        }
    }
}
exports.default = Service;
