"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const topic_1 = require("../../topic");
const tsl_service_1 = __importDefault(require("../tsl_service"));
const tagTopics = __importStar(require("./tag_topics"));
const utils_1 = require("../../utils");
const message_1 = require("../../message");
class TagService extends tsl_service_1.default {
    /**
     * Query tags
     *
     * If it is to obtain all tag information, set `queryParams` to` null`, or set tagKeys in `queryParams` to `[]`
     */
    queryTag(queryParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._validateParams(queryParams);
            if (queryParams && queryParams.tagKeys) {
                assert_1.default(Array.isArray(queryParams.tagKeys), 'queryParams.tagKeys should be an array');
            }
            const params = this._extractParams(queryParams);
            const topic = new topic_1.Topic(tagTopics.queryTagTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, { tags: (queryParams && queryParams.tagKeys) || [] });
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
    /**
     * Update tags
     */
    updateTag(updateParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._validateParams(updateParams);
            assert_1.default(updateParams && updateParams.tags, 'tags is required');
            assert_1.default(Array.isArray(updateParams.tags), 'tags should be an array');
            const params = this._extractParams(updateParams);
            const topic = new topic_1.Topic(tagTopics.updateTagTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, updateParams.tags);
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
    /**
     * Delete tags
     */
    deleteTag(deleteParams) {
        return __awaiter(this, void 0, void 0, function* () {
            this._validateParams(deleteParams);
            assert_1.default(deleteParams && deleteParams.tagKeys, 'tagKeys is required');
            assert_1.default(Array.isArray(deleteParams.tagKeys), 'tagKeys should be an array');
            const params = this._extractParams(deleteParams);
            const topic = new topic_1.Topic(tagTopics.deleteTagTopic, params.deviceInfo);
            const message = new message_1.UpstreamRequest(topic, { tags: (deleteParams && deleteParams.tagKeys) || [] });
            return utils_1.callbackToPromise((_callback) => {
                this._transport.publish(message, params.upstreamOptions, _callback);
            });
        });
    }
}
exports.default = TagService;
