"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sha256_1 = __importDefault(require("crypto-js/sha256"));
const sha1_1 = __importDefault(require("crypto-js/sha1"));
const md5_1 = __importDefault(require("crypto-js/md5"));
const hmac_sha1_1 = __importDefault(require("crypto-js/hmac-sha1"));
const constants_1 = require("../constants");
const signMethodMap = {
    [constants_1.SIGN_METHOD.SHA1]: sha1_1.default,
    [constants_1.SIGN_METHOD.HMACSHA1]: hmac_sha1_1.default,
    [constants_1.SIGN_METHOD.MD5]: md5_1.default,
    [constants_1.SIGN_METHOD.SHA256]: sha256_1.default
};
function isSupportedSignMethod(signMethodName) {
    return !!signMethodMap[signMethodName];
}
exports.isSupportedSignMethod = isSupportedSignMethod;
function sign(params, secret, signMethodName) {
    const signMethod = signMethodMap[signMethodName] || null;
    let signingStr = '';
    if (!isSupportedSignMethod(signMethodName)) {
        throw new Error(`signMethod ${signMethodName} not exists`);
    }
    if (params) {
        signingStr = Object.keys(params).sort().reduce((str, paramName) => (`${str}${paramName}${params[paramName]}`), '');
    }
    signingStr += secret;
    return signMethod(signingStr, secret).toString().toUpperCase();
}
exports.sign = sign;
